\name{logliDerivatives}
\alias{logliDerivatives}
\title{
Calculates the analytical derivatives of the penalized log-likelihood function in the multivariate case. 
}
\description{
Calculates the analytical derivatives of the penalized log-likelihood \deqn{loglike(\mu_1,\ldots,\mu_k,L_1,\ldots,L_k,q_1,\ldots,q_{k-1}|X_1,\ldots,X_n) + c \cdot penalty(L_1, \ldots, L_k)}
of a multivariate (dimension \eqn{D > 1}) normal mixture with respect to the parameter vector \eqn{\theta}.}

\usage{
logliDerivatives(object = NULL, parameter = NULL, x, prop = 0,
 pen = 0, grad = TRUE, hess = TRUE, parallel =  TRUE)
}                           

\arguments{
  \item{object}{
    An object of the class \code{normalMixtureModel}. The derivatives are evaluated at the parameters stored in this object.
    If not supplied, the argument \code{parameter} must be supplied.
}

  \item{parameter}{
   A \eqn{kD + kD(D + 1)/2 + k - 1} vector at which the derivatives are evaluated. k is the number of components and D is the dimension. If it is not supplied, \code{object} must be supplied. If both supplied, 
   only \code{parameter} is used.
}

  \item{x}{
    Data matrix. Each row must be a vector of length D.
     }
     
  \item{prop}{
     Internal parameter.
}
  \item{pen}{
    Positive real number or zero. The weight of the penalization term.
}
  \item{grad}{
    Logical. If TRUE the gradient of the penalized log likelihood will be calculated. 
}
  \item{hess}{
    Logical. If TRUE the hessian of the penalized log likelihood will be calculated. 
}
  \item{parallel}{
      If TRUE, some parts of the calculation are carried out in parallel using OpenMP interface.
}
}
\details{
The parameter vector is given by \deqn{\theta = (\mu_1, \ldots, \mu_k, L_1^{\Delta}, \ldots, L_k^{\Delta}, q_1, \ldots, q_{k-1}),} where \eqn{\mu_i} is a \eqn{D}-vector (mean of the component i),
\eqn{L_i^{\Delta}} is a \eqn{D(D+1)/2} vector, it is the half-vectorization of the Cholesky factor of the inverse of the i'th covariance matrix: \eqn{L_i L_i^{T} = \Sigma_i^{-1}} and \eqn{q_1, \ldots, q_{k-1}} are the weight parameters. The weight of the i'th compoment is thereby given by
\eqn{\frac{q_i^2}{q_1^2 + \ldots+ q_{k-1}^2 + 1}}{q_i^2/(q_1^2 + \ldots + q_{k-1}^2 + 1)}. The length of \eqn{\theta} is \eqn{kD + kD(D + 1)/2 + k - 1}.
}
\value{
A list with 3 entries:

\item{loglikelihood}{A number. The value of the penalized log likelihood at the supplied parameter.}
\item{gradient}{A vector. The gradient of the penalized log likelihood at the supplied parameter.}
\item{hessian}{A matrix. The Hessian at the supplied parameter.}
}

\references{
Alexandrovich, G., "An exact Newton's method for ML estimation in a penalized Gaussian mixture model".
}


\examples{
# define means and covariaces of the components of a two-dimensional two-component mixture.

# means 
mu = cbind(c(1,1),c(3,3))

# covariances
sigma = array(dim=c(2,2,2))
sigma[,,1] = 0.2*c(1,0.8,0.8,1)
sigma[,,2] = 0.4*c(1,-0.5,-0.5,1)


# Create a normalMixtureModel object
object <- createNormalMixtureModel(p = 0.7, mu = mu, sigma = sigma)

# simulate 700 points from the mixture
x <- simulate(object = object, nsim = 700) 

# estimate the parameters of the mixture from the simulated sample
estimate <- gaussianMixtureMLE(x = x, k = 2, penSig = 1) 

# calculate the derivatives of the log-likelihood
devs <- logliDerivatives(object = estimate$estimatedModel, x = x)

# .. or alternative
# extract the parameters from the returned object and convert them into a vector
pars <- convert_object(estimate$estimatedModel)
devs_2 <- logliDerivatives(parameter = pars, x = x)
}

\keyword{Gaussian mixture log likelihood derivatives}